pub struct PersistentBoundingBox {
pub min_x: i32,
pub min_y: i32,
pub min_z: i32,
pub max_x: i32,
pub max_y: i32,
pub max_z: i32,
}Expand description
A structure bounding box stored as six scalar coordinates.
Fields
min_x: i32Minimum X coordinate.
min_y: i32Minimum Y coordinate.
min_z: i32Minimum Z coordinate.
max_x: i32Maximum X coordinate.
max_y: i32Maximum Y coordinate.
max_z: i32Maximum Z coordinate.
Implementations
Sourceimpl PersistentBoundingBox
impl PersistentBoundingBox
Sourcepub const fn from_bounding_box(bounding_box: BoundingBox) -> Self
pub const fn from_bounding_box(bounding_box: BoundingBox) -> Self
Converts a runtime bounding box to its persistent representation.
Sourcepub const fn to_bounding_box(self) -> BoundingBox
pub const fn to_bounding_box(self) -> BoundingBox
Converts this persistent representation to a runtime bounding box.